================
Poisson Approval
================


.. image:: https://img.shields.io/pypi/v/poisson_approval.svg
        :target: https://pypi.python.org/pypi/poisson_approval

.. image:: https://img.shields.io/travis/francois-durand/poisson_approval.svg
        :target: https://travis-ci.org/francois-durand/poisson_approval

.. image:: https://readthedocs.org/projects/poisson-approval/badge/?version=latest
        :target: https://poisson-approval.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/francois-durand/poisson_approval/branch/master/graphs/badge.svg
        :target: https://codecov.io/gh/francois-durand/poisson_approval/branch/master/graphs/badge
        :alt: Code Coverage


Poisson Approval studies the Poisson Game of Approval Voting.


* Free software: GNU General Public License v3
* Documentation: https://poisson-approval.readthedocs.io.

--------
Features
--------

* Implement only the case of 3 candidates.
* Deal with ordinal or cardinal profiles.
* Compute the asymptotic developments of the probability of pivot events when the number of players tends to infinity.
* Compute the best response to a given tau-vector.
* Explore automatically a grid of ordinal profiles or a grid of tau-vectors.
* Perform Monte-Carlo experiments on profiles or tau-vectors.

-------
Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
